@@ -5,7 +5,7 @@ use warnings;
 package MooX::Press;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.029';
+our $VERSION   = '0.030';
 
 use Types::Standard 1.008003 -is, -types;
 use Types::TypeTiny qw(ArrayLike HashLike);
@@ -558,7 +558,7 @@ sub _make_package {
 			}
 			require Import::Into;
 			eval "require $import";
-			$import->import::into($qname, @imports);
+			$import->import::into($qname, @params);
 		}
 	}
 	
